@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: arp.tcl,v 1.16 1999/01/16 20:31:02 jfontain Exp $}
+set rcsId {$Id: arp.tcl,v 1.17 1999/01/18 21:37:40 jfontain Exp $}
 
 
-package provide arp 1.3
+package provide arp 1.4
 package require network 1.2
 
 namespace eval arp {
@@ -20,7 +20,7 @@ namespace eval arp {
         sort {0 increasing}
         switches {-n 0 --numeric 0 -r 1 --remote 1}
     }
-    set file [open [file join $packageDirectory arp.htm]]
+    set file [open [file join $::packageDirectory(arp) arp.htm]]
     set data(helpText) [read $file]                                                           ;# initialize HTML help data from file
     close $file
 
@@ -61,7 +61,7 @@ namespace eval arp {
         }
     }
 
-    set file [open [file join $packageDirectory vendor.txt]]                                ;# directory is set in pkgIndex.tcl file
+    set file [open [file join $::packageDirectory(arp) vendor.txt]]
     while {[gets $file line]>=0} {                              ;# save ethernet address code (first 3 bytes) to vendor name mapping
         if {[scan $line {%2x%2x%2x %s} byte(0) byte(1) byte(2) word]==4} {                   ;# only keep the vendor name first word
             set code [format {%02X:%02X:%02X} $byte(0) $byte(1) $byte(2)]
