@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: cpustats.tcl,v 1.16 1999/01/04 23:07:03 jfontain Exp $}
+set rcsId {$Id: cpustats.tcl,v 1.17 1999/01/23 21:20:10 jfontain Exp $}
 
 
 package provide cpustats 1.3
@@ -9,15 +9,15 @@ package require network 1.2
 
 namespace eval cpustats {
 
+    # use an empty hidden column as index since there is only a single row
     array set data {
         updates 0
-        0,label {} 0,type ascii 0,message {}
+        0,label {} 0,type ascii 0,message {} 0,0 {}
         1,label user 1,type real 1,message {percentage spent in user mode}
         2,label system 2,type real 2,message {percentage spent in system mode}
         3,label nice 3,type real 3,message {percentage spent in nice mode}
         4,label idle 4,type real 4,message {percentage spent in idle mode}
         columns 5
-        sort {0 increasing}
         helpText {
 This is a view of processor activity for the system as a whole.
 
@@ -30,6 +30,9 @@ Examples:
 $ moodss ps -r jdoe@foo.bar.com
 $ moodss ps --remote foo.bar.com
         }
+        views {
+            {visibleColumns {1 2 3 4} sort {1 increasing}}
+        }
         switches {-r 1 --remote 1}
     }
 
@@ -53,7 +56,6 @@ $ moodss ps --remote foo.bar.com
         }
     }
 
-    array set data {0,0 percent}           ;# initialize single row index column with data unit so that viewer labels are meaningful
     array set last {user 0 nice 0 system 0 idle 0}                                                    ;# stored values for last poll
 
     proc update {} {                                               ;# gather cpu statistics (based on the proc man page information)
