@@ -146,7 +146,7 @@ rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jf
 for installation. It requires the tcl, tk, blt and tktable rpms (see INSTALL
 file for more information). Unless you want to work on the moodss source
 code, you can skip the rest of this section.
-<P>For the current version (6.2), the following packages must be installed
+<P>For the current version (6.3), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -441,6 +441,10 @@ viewer mutation by just dropping from the new viewer type icon into the
 existing viewer. It is much quicker than destroying the existing viewer
 and create a new one of the new type, while remembering which data cells
 were monitored by the viewer of the old type.
+<BR>When mutating, if some cells in the current viewer no longer exist
+(they may belong to a disappeared summary table), they are not made a part
+of the new viewer, and a warning message is flashed to the user in the
+message area.
 <H6>
 <A NAME="dragsites"></A>5.1.1.2. Drag sites</H6>
 A table is obviously a drag site. One or more cells can be dragged at once
