@@ -5,15 +5,19 @@ exec wish "$0" "$@"
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
+proc recordRCSId {variableName empty operation} {
+    foreach {header file version} $::rcsId break
+    regsub {,v$} $file {} file
+    set ::sourceVersion($file) $version
+}
+trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
+
+set rcsId {$Id: moodss.tcl,v 1.146 1999/01/31 18:53:45 jfontain Exp $}
+
+
 source utility.tcl
-
-startGatheringRCSIds
 startGatheringPackageDirectories
-
-set rcsId {$Id: moodss.tcl,v 1.144 1999/01/17 20:14:09 jfontain Exp $}
-
-set applicationVersion 6.2
-
+set applicationVersion 6.3
 source getopt.tcl
 
 proc printUsage {exitCode} {
