@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: viewer.tcl,v 1.21 1999/01/04 14:34:28 jfontain Exp $}
+set rcsId {$Id: viewer.tcl,v 1.23 1999/01/29 21:52:03 jfontain Exp $}
 
 class viewer {                                                                             ;# handle viewers related functionalities
     # viewers do not derive from a common interface class but rather support a common set a options through the composite class
@@ -47,7 +47,7 @@ class viewer {
             if {[lsearch -exact [supportedTypes $this] $type]<0} {
                 lifoLabel::flash $::messenger "cannot display data of type $type"
                 bell
-                return
+                return {}                                                                                    ;# give up on all cells
             }
             lappend parsed [list $array $row $column]
         }
@@ -135,12 +135,26 @@ class viewer {
                 break                                                                                                        ;# done
             }
         }
-        view $viewer [cells $this]
+        # only attempt to view cells that still exist (for example, some cells may come from a vanished summary table)
+        set cells {}
+        set count 0
+        foreach cell [cells $this] {
+            if {[info exists $cell]} {
+                lappend cells $cell
+            }
+            incr count
+        }
+        if {[llength $cells]>0} {
+            view $viewer $cells
+        }
+        if {[llength $cells]<$count} {                                                                   ;# warn user when necessary
+            lifoLabel::flash $::messenger {some data cells no longer exist}
+        }
         foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($this,path)] {}
         set level [canvasWindowManager::getStackLevel $::windowManager $widget::($this,path)]
         delete $this                                                                                       ;# delete existing viewer
         # viewer is as destroyable as previously deleted viewer
-        manageViewer $viewer 1  -static $::static -setx $x -sety $y -setwidth $width -setheight $height -level $level
+        manageViewer $viewer 1 -static $::static -setx $x -sety $y -setwidth $width -setheight $height -level $level
     }
 
 }
